@@ -1,10 +1,10 @@
 // lib.rs
 
-mod startup;
+pub mod startup;
 pub use startup::*;
-mod db_util;
+pub mod db_util;
 pub use db_util::*;
-mod str_util;
+pub mod str_util;
 pub use str_util::*;
 
 // EOF
